@@ -18,6 +18,7 @@ package client
 
 import (
 	"bytes"
+	"context"
 	"crypto/rand"
 	"crypto/rsa"
 	"crypto/tls"
@@ -33,6 +34,8 @@ import (
 	"github.com/Shopify/sarama"
 	"github.com/stretchr/testify/assert"
 	commontesting "knative.dev/eventing-kafka/pkg/channel/distributed/common/testing"
+	"knative.dev/pkg/logging"
+	logtesting "knative.dev/pkg/logging/testing"
 )
 
 const (
@@ -115,6 +118,9 @@ Consumer:
 
 // Verify that the JSON fragment can be loaded into a sarama.Config struct
 func TestBuildSaramaConfig(t *testing.T) {
+	logger := logtesting.TestLogger(t)
+	ctx := logging.WithLogger(context.TODO(), logger)
+
 	// Setup Environment
 	commontesting.SetTestEnvironment(t)
 
@@ -126,7 +132,7 @@ func TestBuildSaramaConfig(t *testing.T) {
 	config, err := NewConfigBuilder().
 		WithDefaults().
 		FromYaml(commontesting.OldSaramaConfig).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.NotNil(t, config)
 	assert.True(t, config.Net.SASL.Enable)
@@ -137,7 +143,7 @@ func TestBuildSaramaConfig(t *testing.T) {
 	config, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(commontesting.NewSaramaConfig).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.NotNil(t, config)
 	assert.Equal(t, sarama.V2_3_0_0, config.Version)
@@ -151,21 +157,21 @@ func TestBuildSaramaConfig(t *testing.T) {
 	_, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(regexVersion.ReplaceAllString(commontesting.NewSaramaConfig, "Version: INVALID")).
-		Build()
+		Build(ctx)
 	assert.NotNil(t, err)
 
 	// Verify error when an invalid RootPEMs is provided
 	_, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(strings.Replace(EKDefaultSaramaConfigWithRootCert, "-----BEGIN CERTIFICATE-----", "INVALID CERT DATA", -1)).
-		Build()
+		Build(ctx)
 	assert.NotNil(t, err)
 
 	// Verify that the RootPEMs section is merged properly
 	config, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(EKDefaultSaramaConfigWithRootCert).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.NotNil(t, config.Net.TLS.Config.RootCAs)
 
@@ -173,7 +179,7 @@ func TestBuildSaramaConfig(t *testing.T) {
 	config, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(EKDefaultSaramaConfigWithInsecureSkipVerify).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.True(t, config.Net.TLS.Config.InsecureSkipVerify)
 
@@ -192,7 +198,7 @@ func TestBuildSaramaConfig(t *testing.T) {
 		}).
 		WithVersion(&sarama.V2_0_0_0).
 		WithClientId("newClientId").
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.Equal(t, "foo", config.Net.SASL.User)
 	assert.Equal(t, "newClientId", config.ClientID)
@@ -200,6 +206,9 @@ func TestBuildSaramaConfig(t *testing.T) {
 }
 
 func TestBuildSaramaConfigWithTLSAuth(t *testing.T) {
+	logger := logtesting.TestLogger(t)
+	ctx := logging.WithLogger(context.TODO(), logger)
+
 	// Setup Environment
 	commontesting.SetTestEnvironment(t)
 
@@ -273,7 +282,7 @@ sny569QyyWHk2+FZoWDfjxFZ7CvIdgLJBHc3qUXLsg==
 		WithDefaults().
 		FromYaml(noAuthSaramaYaml).
 		WithAuth(kafkaAuthCfg).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 
 	// Make sure TLS settings are applied from the KafkaAuthConfig
@@ -289,6 +298,9 @@ sny569QyyWHk2+FZoWDfjxFZ7CvIdgLJBHc3qUXLsg==
 }
 
 func TestBuildSaramaConfigWithSASLAuth(t *testing.T) {
+	logger := logtesting.TestLogger(t)
+	ctx := logging.WithLogger(context.TODO(), logger)
+
 	// Setup Environment
 	commontesting.SetTestEnvironment(t)
 
@@ -316,7 +328,7 @@ Metadata:
 		WithDefaults().
 		FromYaml(noAuthSaramaYaml).
 		WithAuth(kafkaAuthCfg).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 
 	// Make sure SASL settings are applied from the KafkaAuthConfig
@@ -332,6 +344,9 @@ Metadata:
 
 // Verify that comparisons of sarama config structs function as expected
 func TestSaramaConfigEqual(t *testing.T) {
+	logger := logtesting.TestLogger(t)
+	ctx := logging.WithLogger(context.TODO(), logger)
+
 	config1 := sarama.NewConfig()
 	config2 := sarama.NewConfig()
 
@@ -387,12 +402,12 @@ func TestSaramaConfigEqual(t *testing.T) {
 	config1, err := NewConfigBuilder().
 		WithDefaults().
 		FromYaml(EKDefaultSaramaConfigWithRootCert).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	config2, err = NewConfigBuilder().
 		WithDefaults().
 		FromYaml(EKDefaultSaramaConfigWithRootCert).
-		Build()
+		Build(ctx)
 	assert.Nil(t, err)
 	assert.True(t, ConfigEqual(config1, config2))
 }
@@ -490,11 +505,13 @@ func TestUpdateSaramaConfigWithKafkaAuthConfig(t *testing.T) {
 
 	for n, tc := range testCases {
 		t.Run(n, func(t *testing.T) {
+			logger := logtesting.TestLogger(t)
+			ctx := logging.WithLogger(context.TODO(), logger)
 
 			// Perform The Test
 			config, err := NewConfigBuilder().
 				WithAuth(tc.kafkaAuthCfg).
-				Build()
+				Build(ctx)
 
 			if err != nil {
 				t.Errorf("error configuring Sarama config with auth :%e", err)
@@ -649,6 +666,51 @@ func TestVerifyCertSkipHostname(t *testing.T) {
 	}
 }
 
+func TestHasSameSettings(t *testing.T) {
+	authConfig := &KafkaAuthConfig{SASL: &KafkaSaslConfig{User: "user1", Password: "password1", SaslType: sarama.SASLTypeOAuth}}
+	saramaConfig := sarama.NewConfig()
+
+	assert.False(t, authConfig.SASL.HasSameSettings(saramaConfig))
+	saramaConfig.Net.SASL.User = "user1"
+	assert.False(t, authConfig.SASL.HasSameSettings(saramaConfig))
+	saramaConfig.Net.SASL.Password = "password1"
+	assert.False(t, authConfig.SASL.HasSameSettings(saramaConfig))
+	saramaConfig.Net.SASL.Mechanism = sarama.SASLTypeOAuth
+	assert.True(t, authConfig.SASL.HasSameSettings(saramaConfig))
+}
+
+func TestHasSameBrokers(t *testing.T) {
+
+	// Define The TestCase Struct
+	type TestCase struct {
+		name  string
+		str   string
+		slice []string
+		same  bool
+	}
+
+	const brokers123 = "broker1,broker2,broker3"
+
+	// Create The TestCases
+	testCases := []TestCase{
+		{name: "3 vs. Identical Slice", str: brokers123, slice: []string{"broker1", "broker2", "broker3"}, same: true},
+		{name: "3 vs. Empty Slice", str: brokers123, slice: []string{}},
+		{name: "3 vs. 1-element Slice", str: brokers123, slice: []string{"broker1"}},
+		{name: "3 vs. 2-element Slice", str: brokers123, slice: []string{"broker1", "broker2"}},
+		{name: "3 vs. 4-element Slice", str: brokers123, slice: []string{"broker1", "broker2", "broker3", "broker4"}},
+		{name: "3 vs. Reversed Slice", str: brokers123, slice: []string{"broker3", "broker2", "broker1"}},
+		{name: "1 vs. 1-element Slice", str: "broker1", slice: []string{"broker1"}, same: true},
+		{name: "0 vs. Empty Slice", str: "", slice: []string{}, same: true},
+	}
+
+	// Run The TestCases
+	for _, testCase := range testCases {
+		t.Run(testCase.name, func(t *testing.T) {
+			assert.Equal(t, testCase.same, HasSameBrokers(testCase.str, testCase.slice))
+		})
+	}
+}
+
 // Lifted from the RSA path of https://golang.org/src/crypto/tls/generate_cert.go.
 func generateCert(t *testing.T) (string, string) {
 	t.Helper()
